bayespy.inference.vmp.nodes.bernoulli.BernoulliMoments.__init__
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.bernoulli

.. automethod:: BernoulliMoments.__init__